@font-face {
  font-family: 'icomoon';
  src: url('fonts/icomoon.eot?obg9cb');
  src: url('fonts/icomoon.eot?obg9cb#iefix') format('embedded-opentype'),
    url('fonts/icomoon.ttf?obg9cb') format('truetype'),
    url('fonts/icomoon.woff?obg9cb') format('woff'),
    url('fonts/icomoon.svg?obg9cb#icomoon') format('svg');
  font-weight: normal;
  font-style: normal;
  font-display: block;
}

[class^="icon-"],
[class*=" icon-"] {
  /* use !important to prevent issues with browser extensions that change fonts */
  font-family: 'icomoon' !important;
  speak: never;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  font-size: 16px;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  /* color: rgb(83, 96, 118); */
}

.icon-bold:before {
  content: "\e906";
}

.icon-down {
  padding-left: 5px;
  font-size: 12px;
  font-weight: bold;
}

.icon-down:before {
  content: "\e907";
}

.icon-italic:before {
  content: "\e908";
}

.icon-ol:before {
  content: "\e909";
}

.icon-ul:before {
  content: "\e90a";
}

.icon-strikethrough:before {
  content: "\e90b";
}

.icon-underline:before {
  content: "\e90c";
}

.icon-forecolor {
  font-size: 16px;
}

.icon-forecolor .path1:before {
  content: "\e905";
}

.icon-forecolor .path1 {
  color: #414D68;
}

.icon-forecolor .path2 {
  color: rgb(0, 0, 0, .1);
}

.icon-forecolor .path2:before {
  content: "\e904";
  margin-left: -1em;
}

.icon-forecolor .path3:before {
  content: "\e90f";
  margin-left: -1em;
}

.icon-backcolor {
  font-size: 16px;
}

.icon-backcolor .path1:before {
  content: "\e905";
}

.icon-backcolor .path1 {
  color: #414D68;
}

.icon-backcolor .path2 {
  color: rgb(0, 0, 0, .1);
}

.icon-backcolor .path2:before {
  content: "\e904";
  margin-left: -1em;
}

.icon-backcolor .path3:before {
  content: "\e903";
  margin-left: -1em;
}